View source: R/model_smimodel.R
| allpred_index | R Documentation |
Constructs vectors of coefficients for each index including a coefficient for all the predictors that are entering indices. i.e. if a coefficient is not provided for a particular predictor in a particular index, the function will replace the missing coefficient with a zero.
allpred_index(num_pred, num_ind, ind_pos, alpha)
num_pred |
Number of predictors. |
num_ind |
Number of indices. |
ind_pos |
A list of length = |
alpha |
A vector of index coefficients. |
A list containing the following components:
alpha_init_new |
A
|
index |
An |
index_positions |
A list of length = |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.