View source: R/prediction_intervals.R
| blockBootstrap | R Documentation |
Generates possible future sample paths by applying the single season block bootstrap method.
blockBootstrap(
object,
newdata,
resids,
preds,
season.period = 1,
m = 1,
num.futures = 1000,
exclude.trunc = NULL,
recursive = FALSE,
recursive_colRange = NULL
)
object |
Fitted model object. |
newdata |
Test data set. Must be a data set of class |
resids |
In-sample residuals from the fitted model. |
preds |
Predictions for the test set (i.e. data for the forecast horizon). |
season.period |
Length of the seasonal period. |
m |
Multiplier. (Block size = |
num.futures |
Number of possible future sample paths to be generated. |
exclude.trunc |
The names of the predictor variables that should not be truncated for stable predictions as a character string. |
recursive |
Whether to obtain recursive forecasts or not (default - FALSE). |
recursive_colRange |
If |
A matrix of simulated future sample paths.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.