View source: R/model_backward.R
| eliminate | R Documentation |
Eliminates a specified variable and fits a nonparametric additive model with
remaining variables, and returns validation set MSE. This is an internal
function of the package, and designed to be called from
model_backward.
eliminate(
ind,
train,
val,
yvar,
family = gaussian(),
s.vars = NULL,
s.basedim = NULL,
linear.vars = NULL,
exclude.trunc = NULL,
recursive = FALSE,
recursive_colRange = NULL
)
ind |
An |
train |
The data set on which the model(s) will be trained. Must be a
data set of class |
val |
Validation data set. (The data set on which the model selection
will be performed.) Must be a data set of class |
yvar |
Name of the response variable as a character string. |
family |
A description of the error distribution and link function to be
used in the model (see |
s.vars |
A |
s.basedim |
Dimension of the bases used to represent the smooth terms
corresponding to |
linear.vars |
A |
exclude.trunc |
The names of the predictor variables that should not be
truncated for stable predictions as a character string. (Since the
nonlinear functions are estimated using splines, extrapolation is not
desirable. Hence, if any predictor variable in |
recursive |
Whether to obtain recursive forecasts or not (default -
|
recursive_colRange |
If |
A numeric.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.