View source: R/model_smimodel.R
| inner_update | R Documentation |
Iteratively updates index coefficients and non-linear functions using mixed
integer programming. (A helper function used within
update_smimodelFit; users are not expected to directly call
this function.)
inner_update(
x,
data,
yvar,
family = gaussian(),
index.vars,
s.vars,
linear.vars,
num_ind,
dgz,
alpha_old,
lambda0 = 1,
lambda2 = 1,
M = 10,
max.iter = 50,
tol = 0.001,
TimeLimit = Inf,
MIPGap = 1e-04,
NonConvex = -1,
verbose = list(solver = FALSE, progress = FALSE)
)
x |
Fitted |
data |
Training data set on which models will be trained. Should be a
|
yvar |
Name of the response variable as a character string. |
family |
A description of the error distribution and link function to be
used in the model (see |
index.vars |
A |
s.vars |
A |
linear.vars |
A |
num_ind |
Number of indices. |
dgz |
The |
alpha_old |
Current vector of index coefficients. |
lambda0 |
Penalty parameter for L0 penalty. |
lambda2 |
Penalty parameter for L2 penalty. |
M |
Big-M value to be used in MIP. |
max.iter |
Maximum number of MIP iterations performed to update index coefficients for a given model. |
tol |
Tolerance for loss. |
TimeLimit |
A limit for the total time (in seconds) expended in a single MIP iteration. |
MIPGap |
Relative MIP optimality gap. |
NonConvex |
The strategy for handling non-convex quadratic objectives or non-convex quadratic constraints in Gurobi solver. |
verbose |
A named list controlling verbosity options. Defaults to
|
A list containing following elements:
best_alpha |
The vector of best index coefficient estimates. |
min_loss |
Minimum value of the objective function(loss). |
index.ind |
An |
ind_pos |
A list that indicates which predictors belong to which index,
corresponding to |
X_new |
A matrix of selected predictor variables, corresponding to
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.