View source: R/model_smimodel.R
| new_smimodelFit | R Documentation |
smimodelFitConstructs an object of class smimodelFit using the information passed
to arguments.
new_smimodelFit(
data,
yvar,
neighbour = 0,
family = gaussian(),
index.vars,
initialise = c("additive", "linear", "userInput"),
index.ind = NULL,
index.coefs = NULL,
s.vars = NULL,
linear.vars = NULL
)
data |
Training data set on which models will be trained. Must be a data
set of class |
yvar |
Name of the response variable as a character string. |
neighbour |
|
family |
A description of the error distribution and link function to be
used in the model (see |
index.vars |
A |
initialise |
The model structure with which the estimation process
should be initialised. The default is "additive", where the initial model
will be a nonparametric additive model. The other options are "linear" -
linear regression model (i.e. a special case single-index model, where the
initial values of the index coefficients are obtained through a linear
regression), and "userInput" - user specifies the initial model structure
(i.e. the number of indices and the placement of index variables among
indices) and the initial index coefficients through |
index.ind |
If |
index.coefs |
If |
s.vars |
A |
linear.vars |
A |
A list of initial model information. For descriptions of the list
elements see make_smimodelFit).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.