View source: R/prediction_intervals.R
| possibleFutures_benchmark | R Documentation |
Generates possible future sample paths (multi-step) using residuals of a fitted benchmark model through recursive forecasting.
possibleFutures_benchmark(
object,
newdata,
bootstraps,
exclude.trunc = NULL,
recursive_colRange
)
object |
A fitted model object of the class |
newdata |
The set of new data on for which the forecasts are required
(i.e. test set; should be a |
bootstraps |
Generated matrix of bootstrapped residual series. |
exclude.trunc |
The names of the predictor variables that should not be truncated for stable predictions as a character string. |
recursive_colRange |
The range of column numbers in |
A list containing the following components:
firstFuture |
A
|
future_cols |
A list of multi-steps-ahead simulated futures, where
each list element corresponds to each 1-step-ahead simulated future in
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.