randomBlock: Randomly sampling a block

View source: R/prediction_intervals.R

randomBlockR Documentation

Randomly sampling a block

Description

Samples a block of specified size from a given series starting form a random point in the series.

Usage

randomBlock(series, block.size)

Arguments

series

A series from which a block should be sampled.

block.size

Size of the block to be sampled.

Value

A numeric vector.


smimodel documentation built on April 8, 2026, 5:06 p.m.