Skip to contents

Appropriately removes existing (actual) values from the specified column range (lagged response columns) of a given data set (typically a test set for which recursive forecasting is required).

Usage

remove_lags(data, recursive_colRange)

Arguments

data

Data set (a tibble) from which the actual lagged values should be removed.

recursive_colRange

The range of column numbers in data from which lagged values should be removed.

Value

A tibble.