View source: R/prediction_intervals.R
| residBootstrap | R Documentation |
Generates multiple replications of single season block bootstrap series.
residBootstrap(x, season.period = 1, m = 1, num.bootstrap = 1000)
x |
A series of residuals from which bootstrap series to be generated. |
season.period |
Length of the seasonal period. |
m |
Multiplier. (Block size = |
num.bootstrap |
Number of bootstrap series to be generated. |
A matrix of bootstrapped series.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.