seasonBootstrap: Single season block bootstrap

View source: R/prediction_intervals.R

seasonBootstrapR Documentation

Single season block bootstrap

Description

Generates a single replication of single season block bootstrap series.

Usage

seasonBootstrap(x, season.period = 1, m = 1)

Arguments

x

A series of residuals from which bootstrap series to be generated.

season.period

Length of the seasonal period.

m

Multiplier. (Block size = season.period * m)

Value

A numeric vector.


smimodel documentation built on April 8, 2026, 5:06 p.m.