unscaling: Unscale a fitted 'smimodel'

View source: R/model_smimodel.R

unscalingR Documentation

Unscale a fitted smimodel

Description

Transforms back the index coefficients to suit original-scale index variables if the same were scaled when estimating the smimodel (happens in initialise = "ppr" in model_smimodel or greedy_smimodel). Users are not expected to directly use this function; usually called within smimodel.fit.

Usage

unscaling(object, scaledInfo)

Arguments

object

A smimodel object.

scaledInfo

The list returned from a call of the function scaling.

Value

A smimodel object.


smimodel documentation built on April 8, 2026, 5:06 p.m.