View source: R/model_smimodel.R
| update_smimodelFit | R Documentation |
smimodelFitOptimises and updates a given smimodelFit.
update_smimodelFit(
object,
data,
lambda0 = 1,
lambda2 = 1,
M = 10,
max.iter = 50,
tol = 0.001,
tolCoefs = 0.001,
TimeLimit = Inf,
MIPGap = 1e-04,
NonConvex = -1,
verbose = list(solver = FALSE, progress = FALSE),
...
)
object |
A |
data |
Training data set on which models will be trained. Must be a data
set of class |
lambda0 |
Penalty parameter for L0 penalty. |
lambda2 |
Penalty parameter for L2 penalty. |
M |
Big-M value to be used in MIP. |
max.iter |
Maximum number of MIP iterations performed to update index coefficients for a given model. |
tol |
Tolerance for the objective function value (loss) of MIP. |
tolCoefs |
Tolerance for coefficients. |
TimeLimit |
A limit for the total time (in seconds) expended in a single MIP iteration. |
MIPGap |
Relative MIP optimality gap. |
NonConvex |
The strategy for handling non-convex quadratic objectives or non-convex quadratic constraints in Gurobi solver. |
verbose |
A named list controlling verbosity options. Defaults to
|
... |
Other arguments not currently used. |
A list of optimised model information. For descriptions of the list
elements see make_smimodelFit).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.