Possible future sample paths (multi-step) from residuals of a fitted benchmark model
Source:R/prediction_intervals.R
possibleFutures_benchmark.RdGenerates possible future sample paths (multi-step) using residuals of a fitted benchmark model through recursive forecasting.
Usage
possibleFutures_benchmark(
object,
newdata,
bootstraps,
exclude.trunc = NULL,
recursive_colRange
)Arguments
- object
A fitted model object of the class
backward,pprFit, orgaimFit.- newdata
The set of new data on for which the forecasts are required (i.e. test set; should be a
tsibble).- bootstraps
Generated matrix of bootstrapped residual series.
- exclude.trunc
The names of the predictor variables that should not be truncated for stable predictions as a character string.
- recursive_colRange
The range of column numbers in
newdatato be filled with forecasts.