R/prediction_intervals.R
randomBlock.Rd
Samples a block of specified size from a given series starting form a random point in the series.
randomBlock(series, block.size)
A series from which a block should be sampled.
Size of the block to be sampled.
A numeric vector.
numeric