View source: R/prediction_intervals.R
| randomBlock | R Documentation |
Samples a block of specified size from a given series starting form a random point in the series.
randomBlock(series, block.size)
series |
A series from which a block should be sampled. |
block.size |
Size of the block to be sampled. |
A numeric vector.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.