Remove actual values from a data set for recursive forecasting
Source:R/prediction_intervals.R
remove_lags.RdAppropriately removes existing (actual) values from the specified column range (lagged response columns) of a given data set (typically a test set for which recursive forecasting is required).