View source: R/model_smimodel.R
| scaling | R Documentation |
Scales the columns of the data corresponding to index.vars.
scaling(data, index.vars)
data |
Training data set on which models will be trained. Should be a
|
index.vars |
A character vector of names of the predictor variables for which indices should be estimated. |
A list containing the following components:
scaled_data |
The
scaled data set of class |
scaled_info |
A named
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.