View source: R/prediction_intervals.R
| seasonBootstrap | R Documentation |
Generates a single replication of single season block bootstrap series.
seasonBootstrap(x, season.period = 1, m = 1)
x |
A series of residuals from which bootstrap series to be generated. |
season.period |
Length of the seasonal period. |
m |
Multiplier. (Block size = |
A numeric vector.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.