| truncate_vars | R Documentation |
Truncates predictors to be in the in-sample range to avoid spline extrapolation.
truncate_vars(range.object, data, cols.trunc)
range.object |
A matrix containing range of each predictor variable. Should be a matrix with two rows for min and max, and the columns should correspond to variables. |
data |
Out-of-sample data set of which variables should be truncated. |
cols.trunc |
Column names of the variables to be truncated. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.