Transforms back the index coefficients to suit original-scale index variables
if the same were scaled when estimating the smimodel (happens in
initialise = "ppr" in model_smimodel or
greedy_smimodel). Users are not expected to directly use this
function; usually called within smimodel.fit.
Arguments
- object
A
smimodelobject.- scaledInfo
The list returned from a call of the function
scaling.