View source: R/model_smimodel.R
| unscaling | R Documentation |
smimodelTransforms back the index coefficients to suit original-scale index variables
if the same were scaled when estimating the smimodel (happens in
initialise = "ppr" in model_smimodel or
greedy_smimodel). Users are not expected to directly use this
function; usually called within smimodel.fit.
unscaling(object, scaledInfo)
object |
A |
scaledInfo |
The list returned from a call of the function
|
A smimodel object.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.